# clean-text-my

## Description
The `clean-text-my` repository contains a Python script that performs a deduplication process on a text dataset. This process is implemented based on the code provided in the [Jupyter Notebook](https://github.com/malaysia-ai/text-dataset-dedup).

## Installing from the PyPI
```console
$ pip install clean-text-my
```
